@@ -243,9 +243,8 @@ addons_notify_load_status_cb (MidoriView*      view,
                               MidoriExtension* extension)
 {
     const gchar* uri = midori_view_get_display_uri (view);
-    WebKitWebView* web_view = WEBKIT_WEB_VIEW (midori_view_get_web_view (view));
 
-    if (webkit_web_view_get_view_source_mode (web_view))
+    if (midori_tab_get_view_source (MIDORI_TAB (view)))
         return;
 
     if (uri && *uri)
@@ -930,10 +929,16 @@ js_metadata_from_file (const gchar* filename,
                 /* We don't support these, so abort here */
                 g_free (line);
                 g_io_channel_shutdown (channel, false, 0);
-                g_slist_free (*includes);
-                g_slist_free (*excludes);
-                *includes = NULL;
-                *excludes = NULL;
+                if (includes != NULL)
+                {
+                    g_slist_free (*includes);
+                    *includes = NULL;
+                }
+                if (excludes != NULL)
+                {
+                    g_slist_free (*excludes);
+                    *excludes = NULL;
+                }
                 return FALSE;
             }
              else if (includes && g_str_has_prefix (line, "// @include"))
