@@ -15,7 +15,7 @@
 
 #include <glib/gi18n.h>
 
-#include <webkit/webkit.h>
+#include "katze/katze.h"
 
 /**
  * SECTION:katze-item
@@ -457,7 +457,7 @@ katze_item_get_pixbuf (KatzeItem* item,
 static void
 katze_item_image_destroyed_cb (GtkWidget* image,
                                KatzeItem* item);
-
+#ifndef HAVE_WEBKIT2
 #if WEBKIT_CHECK_VERSION (1, 3, 13)
 static void
 #if WEBKIT_CHECK_VERSION (1, 8, 0)
@@ -482,11 +482,13 @@ katze_item_icon_loaded_cb (WebKitIconDatabase*    database,
     }
 }
 #endif
+#endif
 
 static void
 katze_item_image_destroyed_cb (GtkWidget* image,
                                KatzeItem* item)
 {
+#ifndef HAVE_WEBKIT2
     #if WEBKIT_CHECK_VERSION (1, 8, 0)
     g_signal_handlers_disconnect_by_func (webkit_get_favicon_database (),
         katze_item_icon_loaded_cb, image);
@@ -494,6 +496,7 @@ katze_item_image_destroyed_cb (GtkWidget* image,
     g_signal_handlers_disconnect_by_func (webkit_get_icon_database (),
         katze_item_icon_loaded_cb, image);
     #endif
+#endif
     g_object_unref (item);
 }
 
@@ -528,6 +531,7 @@ katze_item_get_image (KatzeItem* item,
     g_object_set_data (G_OBJECT (image), "KatzeItem", g_object_ref (item));
     g_signal_connect (image, "destroy",
         G_CALLBACK (katze_item_image_destroyed_cb), item);
+#ifndef HAVE_WEBKIT2
     #if WEBKIT_CHECK_VERSION (1, 8, 0)
     g_signal_connect (webkit_get_favicon_database (), "icon-loaded",
         G_CALLBACK (katze_item_icon_loaded_cb), image);
@@ -535,6 +539,7 @@ katze_item_get_image (KatzeItem* item,
     g_signal_connect (webkit_get_icon_database (), "icon-loaded",
         G_CALLBACK (katze_item_icon_loaded_cb), image);
     #endif
+#endif
     return image;
 }
 
