@@ -12,6 +12,7 @@
 
 #include "midori-bookmarks.h"
 #include "panels/midori-bookmarks.h"
+#include "midori-app.h"
 #include "midori-array.h"
 #include "sokoke.h"
 #include "midori-core.h"
@@ -24,12 +25,12 @@
     #include <unistd.h>
 #endif
 
-#ifdef G_ENABLE_DEBUG
-void midori_bookmarks_dbtracer(void* dummy, const char* query)
+void
+midori_bookmarks_dbtracer (void*       dummy,
+                           const char* query)
 {
     g_printerr ("%s\n", query);
 }
-#endif
 
 void
 midori_bookmarks_add_item_cb (KatzeArray* array,
@@ -129,9 +130,8 @@ midori_bookmarks_import_from_old_db (sqlite3*     db,
 }
 #undef _APPEND_TO_SQL_ERRORMSG
 
-sqlite3*
-midori_bookmarks_initialize (KatzeArray*  array,
-                             char**       errmsg)
+KatzeArray*
+midori_bookmarks_new (char** errmsg)
 {
     sqlite3* db;
     gchar* oldfile;
@@ -140,30 +140,25 @@ midori_bookmarks_initialize (KatzeArray*  array,
     const gchar* create_stmt;
     gchar* sql_errmsg = NULL;
     gchar* import_errmsg = NULL;
+    KatzeArray* array;
 
     g_return_val_if_fail (errmsg != NULL, NULL);
 
-    oldfile = g_build_filename (midori_paths_get_config_dir (), "bookmarks.db", NULL);
+    oldfile = midori_paths_get_config_filename_for_writing ("bookmarks.db");
     oldfile_exists = g_access (oldfile, F_OK) == 0;
-    newfile = g_build_filename (midori_paths_get_config_dir (), "bookmarks_v2.db", NULL);
+    newfile = midori_paths_get_config_filename_for_writing ("bookmarks_v2.db");
     newfile_did_exist = g_access (newfile, F_OK) == 0;
 
     /* sqlite3_open will create the file if it did not exists already */
     if (sqlite3_open (newfile, &db) != SQLITE_OK)
     {
-        if (db)
-            *errmsg = g_strdup_printf (_("failed to open database: %s\n"),
-                    sqlite3_errmsg (db));
-        else
-            *errmsg = g_strdup (_("failed to open database\n"));
-
+        *errmsg = g_strdup_printf (_("Failed to open database: %s\n"),
+            db ? sqlite3_errmsg (db) : "(db = NULL)");
         goto init_failed;
     }
 
-#ifdef G_ENABLE_DEBUG
     if (midori_debug ("bookmarks"))
         sqlite3_trace (db, midori_bookmarks_dbtracer, NULL);
-#endif
 
     create_stmt =     /* Table structure */
         "CREATE TABLE IF NOT EXISTS bookmarks "
@@ -261,17 +256,9 @@ midori_bookmarks_initialize (KatzeArray*  array,
         /* initial creation */
         if (sqlite3_exec (db, create_stmt, NULL, NULL, &sql_errmsg) != SQLITE_OK)
         {
-
-            if (errmsg)
-            {
-                if (sql_errmsg)
-                {
-                    *errmsg = g_strdup_printf (_("could not create bookmarks table: %s\n"), sql_errmsg);
-                    sqlite3_free (sql_errmsg);
-                }
-                else
-                    *errmsg = g_strdup (_("could not create bookmarks table"));
-            }
+            *errmsg = g_strdup_printf (_("Couldn't create bookmarks table: %s\n"),
+                sql_errmsg ? sql_errmsg : "(err = NULL)");
+            sqlite3_free (sql_errmsg);
 
             /* we can as well remove the new file */
             g_unlink (newfile);
@@ -284,27 +271,21 @@ midori_bookmarks_initialize (KatzeArray*  array,
         /* import from old db */
         if (!midori_bookmarks_import_from_old_db (db, oldfile, &import_errmsg))
         {
-            if (errmsg)
-            {
-                if (import_errmsg)
-                {
-                    *errmsg = g_strdup_printf (_("could not import from old database: %s\n"), import_errmsg);
-                    g_free (import_errmsg);
-                }
-                else
-                    *errmsg = g_strdup_printf (_("could not import from old database"));
-            }
+            *errmsg = g_strdup_printf (_("Couldn't import from old database: %s\n"),
+                import_errmsg ? import_errmsg : "(err = NULL)");
+            g_free (import_errmsg);
         }
 
     init_success:
         g_free (newfile);
         g_free (oldfile);
+        array = katze_array_new (KATZE_TYPE_ARRAY);
         g_signal_connect (array, "add-item",
                           G_CALLBACK (midori_bookmarks_add_item_cb), db);
         g_signal_connect (array, "remove-item",
                           G_CALLBACK (midori_bookmarks_remove_item_cb), db);
-
-        return db;
+        g_object_set_data (G_OBJECT (array), "db", db);
+        return array;
 
     init_failed:
         g_free (newfile);
@@ -333,3 +314,14 @@ midori_bookmarks_import (const gchar* filename,
     }
     midori_bookmarks_import_array_db (db, bookmarks, 0);
 }
+
+void
+midori_bookmarks_on_quit (KatzeArray* array)
+{
+    g_return_if_fail (KATZE_IS_ARRAY (array));
+
+    sqlite3* db = g_object_get_data (G_OBJECT (array), "db");
+    g_return_if_fail (db != NULL);
+    sqlite3_close (db);
+}
+
