@@ -389,7 +389,10 @@ midori_extension_activate_cb (MidoriExtension* extension,
                 setting_->value = g_key_file_get_string_list (extension->priv->key_file,
                     "settings", setting->name, &setting_->length, NULL);
                 if (setting_->value == NULL)
+                {
                     setting_->value = g_strdupv (setting_->default_value);
+                    setting_->length = setting_->default_length;
+                }
             }
             else
                 setting_->value = g_strdupv (setting_->default_value);
@@ -555,6 +558,9 @@ midori_extension_load_from_folder (MidoriApp* app,
         const gchar* filename;
         while (keys && (filename = keys[i++]))
             midori_extension_activate_gracefully (app, extension_path, filename, activate);
+        /* FIXME need proper stock extension mechanism */
+        GObject* extension = midori_extension_activate_gracefully (app, extension_path, "libtransfers." G_MODULE_SUFFIX, activate);
+        g_assert (extension != NULL);
     }
     else
     {
@@ -628,7 +634,7 @@ midori_extension_load_from_file (const gchar* extension_path,
     return extension;
 }
 
-void
+GObject*
 midori_extension_activate_gracefully (MidoriApp*   app,
                                       const gchar* extension_path,
                                       const gchar* filename,
@@ -648,7 +654,10 @@ midori_extension_activate_gracefully (MidoriApp*   app,
         katze_array_add_item (extensions, extension);
         g_object_unref (extensions);
         g_object_unref (extension);
+        return NULL;
     }
+    else
+        return extension;
 }
 
 static void
@@ -662,6 +671,9 @@ midori_extension_add_to_list (MidoriApp*       app,
     g_return_if_fail (KATZE_IS_ARRAY (extensions));
     if (katze_array_get_item_index (extensions, extension) >= 0)
         return;
+    /* FIXME need proper stock extension mechanism */
+    if (!strcmp (filename, "libtransfers." G_MODULE_SUFFIX))
+        return;
 
     katze_array_add_item (extensions, extension);
     g_object_unref (extensions);
@@ -687,7 +699,7 @@ midori_extension_activate (GObject*     extension,
     {
         if (filename != NULL)
             midori_extension_add_to_list (app, MIDORI_EXTENSION (extension), filename);
-        if (activate)
+        if (activate && !midori_extension_is_active (MIDORI_EXTENSION (extension)))
             g_signal_emit_by_name (extension, "activate", app);
     }
     else if (KATZE_IS_ARRAY (extension))
@@ -710,7 +722,8 @@ midori_extension_activate (GObject*     extension,
                     midori_extension_add_to_list (app, extension_item, filename);
                     g_object_set_data_full (G_OBJECT (extension_item), "filename", g_strdup (filename), g_free);
                 }
-                if (activate && filename && strstr (filename, key))
+                if (activate && !midori_extension_is_active (MIDORI_EXTENSION (extension_item))
+                 && filename && strstr (filename, key))
                 {
                     g_signal_emit_by_name (extension_item, "activate", app);
                     success = TRUE;
@@ -777,29 +790,6 @@ midori_extension_is_active (MidoriExtension* extension)
     return extension->priv->active > 0;
 }
 
-/**
- * midori_extension_is_deactivating:
- * @extension: a #MidoriExtension
- *
- * Determines if @extension is currently in the process of
- * being deactivated.
- *
- * Extensions remain fully functional even while being
- * deactivated, so you can for instance still save settings
- * but you may need to cleanup during deactivation.
- *
- * Return value: %TRUE if @extension is deactivating
- *
- * Since: 0.1.7
- **/
-gboolean
-midori_extension_is_deactivating (MidoriExtension* extension)
-{
-    g_return_val_if_fail (MIDORI_IS_EXTENSION (extension), FALSE);
-
-    return extension->priv->active == 2;
-}
-
 /**
  * midori_extension_deactivate:
  * @extension: a #MidoriExtension
@@ -811,7 +801,6 @@ midori_extension_deactivate (MidoriExtension* extension)
 {
     g_return_if_fail (midori_extension_is_active (extension));
 
-    extension->priv->active = 2;
     g_signal_emit (extension, signals[DEACTIVATE], 0);
     extension->priv->active = 0;
     katze_object_assign (extension->priv->app, NULL);
