@@ -19,7 +19,6 @@
 #include "midori-panel.h"
 #include "panels/midori-bookmarks.h"
 #include "panels/midori-history.h"
-#include "panels/midori-transfers.h"
 #include "sokoke.h"
 #include <glib/gi18n-lib.h>
 
@@ -231,6 +230,11 @@ midori_private_app_new (const gchar* config,
         midori_browser_assert_action (browser, execute_commands[i]);
         midori_browser_activate_action (browser, execute_commands[i]);
     }
+
+    /* FIXME need proper stock extension mechanism */
+    midori_browser_activate_action (browser, "libtransfers." G_MODULE_SUFFIX "=true");
+    g_assert (g_module_error () == NULL);
+
     return browser;
 }
 
@@ -267,9 +271,6 @@ midori_app_add_browser_cb (MidoriApp*     app,
     addon = g_object_new (MIDORI_TYPE_HISTORY, "app", app, "visible", TRUE, NULL);
     midori_panel_append_page (MIDORI_PANEL (panel), MIDORI_VIEWABLE (addon));
 
-    addon = g_object_new (MIDORI_TYPE_TRANSFERS, "app", app, "visible", TRUE, NULL);
-    midori_panel_append_page (MIDORI_PANEL (panel), MIDORI_VIEWABLE (addon));
-
     /* Extensions */
     g_signal_connect (browser, "show-preferences",
         G_CALLBACK (midori_browser_privacy_preferences_cb), app);
@@ -334,9 +335,8 @@ midori_frontend_diagnostic_dialog (MidoriApp*         app,
 
     dialog = gtk_message_dialog_new (
         NULL, 0, GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE,
-        _("Midori seems to have crashed the last time it was opened. "
-          "If this happened repeatedly, try one of the following options "
-          "to solve the problem."));
+        _("Midori crashed the last time it was opened. You can report the problem at %s."),
+        PACKAGE_BUGREPORT);
     gtk_window_set_skip_taskbar_hint (GTK_WINDOW (dialog), FALSE);
     gtk_window_set_title (GTK_WINDOW (dialog), g_get_application_name ());
     content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
@@ -442,15 +442,19 @@ midori_normal_app_new (const gchar* config,
     MidoriApp* app = midori_app_new (nickname);
     if (midori_app_instance_is_running (app))
     {
-        gboolean result = FALSE;
-        GtkWidget* dialog;
-
-        if (execute_commands != NULL && midori_app_send_command (app, execute_commands))
-            return NULL;
-        if (open_uris != NULL && midori_app_instance_send_uris (app, open_uris))
-            return NULL;
-        if (!execute_commands && !open_uris && midori_app_instance_send_new_browser (app))
-            return NULL;
+        /* It makes no sense to show a crash dialog while running */
+        if (!diagnostic_dialog)
+        {
+            gboolean success = FALSE;
+            if (execute_commands != NULL && midori_app_send_command (app, execute_commands))
+                success = TRUE;
+            if (open_uris != NULL && midori_app_instance_send_uris (app, open_uris))
+                success = TRUE;
+            if (!execute_commands && !open_uris && midori_app_instance_send_new_browser (app))
+                success = TRUE;
+            if (success)
+                return NULL;
+        }
 
         /* FIXME: We mustn't lose the URL here; either instance is freezing or inside a crash dialog */
         sokoke_message_dialog (GTK_MESSAGE_INFO,
