@@ -478,7 +478,7 @@ midori_location_action_popup_position (MidoriLocationAction* action,
     GtkWidget* popup = action->popup;
     GtkWidget* widget = action->entry;
     GdkWindow* window = gtk_widget_get_window (widget);
-    gint wx, wy, x_border, y_border, items;
+    gint wx, wy, items;
     GtkRequisition menu_req;
     GtkRequisition widget_req;
     GdkScreen* screen;
@@ -504,8 +504,6 @@ midori_location_action_popup_position (MidoriLocationAction* action,
     wx += alloc.x;
     wy += alloc.y + (alloc.height - widget_req.height) / 2;
     #endif
-    /* _gtk_entry_get_borders (GTK_ENTRY (widget), &x_border, &y_border); */
-    x_border = y_border = 0;
 
     gtk_tree_view_column_cell_get_size (
         gtk_tree_view_get_column (GTK_TREE_VIEW (action->treeview), 0),
@@ -526,7 +524,7 @@ midori_location_action_popup_position (MidoriLocationAction* action,
         items = MIN (matches, ((monitor.y + wy) / height) - 1);
     else
         items = MIN (matches, ((toplevel_height - wy) / height) - 1);
-    width = MIN (alloc.width, monitor.width) - 2 * x_border;
+    width = MIN (alloc.width, monitor.width);
 
     gtk_tree_view_columns_autosize (GTK_TREE_VIEW (action->treeview));
     #if GTK_CHECK_VERSION (3, 0, 0)
@@ -1283,6 +1281,7 @@ midori_location_action_focus_out_event_cb (GtkWidget*   widget,
 #endif
 
 #if defined (HAVE_LIBSOUP_2_34_0)
+#ifndef HAVE_WEBKIT2
 static GHashTable* message_map = NULL;
 void
 midori_map_add_message (SoupMessage* message)
@@ -1300,10 +1299,14 @@ midori_map_get_message (SoupMessage* message)
     SoupURI* uri = soup_message_get_uri (message);
     SoupMessage* full;
     g_return_val_if_fail (uri && uri->host, message);
+    if (message_map == NULL)
+        message_map = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_object_unref);
     full = g_hash_table_lookup (message_map, uri->host);
-    g_return_val_if_fail (full, message);
-    return full;
+    if (full != NULL)
+        return full;
+    return message;
 }
+#endif
 
 #ifdef HAVE_GCR
 typedef enum {
@@ -1357,53 +1360,55 @@ midori_location_action_cert_response_cb (GtkWidget*      dialog,
 const gchar*
 midori_location_action_tls_flags_to_string (GTlsCertificateFlags tls_flags)
 {
-    const gchar* tls_error;
     if (tls_flags & G_TLS_CERTIFICATE_UNKNOWN_CA)
-        tls_error = _("The signing certificate authority is not known.");
+        return _("The signing certificate authority is not known.");
     else if (tls_flags & G_TLS_CERTIFICATE_BAD_IDENTITY)
-        tls_error = _("The certificate does not match the expected identity of the site that it was retrieved from.");
+        return _("The certificate does not match the expected identity of the site that it was retrieved from.");
     else if(tls_flags & G_TLS_CERTIFICATE_NOT_ACTIVATED)
-        tls_error = _("The certificate's activation time is still in the future.");
+        return _("The certificate's activation time is still in the future.");
     else if (tls_flags & G_TLS_CERTIFICATE_EXPIRED)
-        tls_error = _("The certificate has expired");
+        return _("The certificate has expired");
     else if (tls_flags & G_TLS_CERTIFICATE_REVOKED)
-        tls_error = _("The certificate has been revoked according to the GTlsConnection's certificate revocation list.");
+        return _("The certificate has been revoked according to the GTlsConnection's certificate revocation list.");
     else if (tls_flags & G_TLS_CERTIFICATE_INSECURE)
-        tls_error = _("The certificate's algorithm is considered insecure.");
+        return _("The certificate's algorithm is considered insecure.");
     else if (tls_flags & G_TLS_CERTIFICATE_GENERIC_ERROR)
-        tls_error = _("Some other error occurred validating the certificate.");
-    else
-        tls_error = "Unknown GTLSCertificateFlags value";
-    return tls_error;
+        return _("Some other error occurred validating the certificate.");
+    else if (tls_flags == 0)
+        g_return_val_if_reached ("GTLSCertificateFlags is 0");
+    g_return_val_if_reached ("Unknown GTLSCertificateFlags value");
 }
 
-void
+static void
 midori_location_action_show_page_info (GtkWidget* widget,
                                        GtkBox*    box,
                                        GtkWidget* dialog)
 {
-#ifndef HAVE_WEBKIT2
+    GTlsCertificate* tls_cert;
+    GTlsCertificateFlags tls_flags;
+    gchar* hostname;
+
     MidoriBrowser* browser = midori_browser_get_for_widget (widget);
     MidoriView* view = MIDORI_VIEW (midori_browser_get_current_tab (browser));
+    #ifdef HAVE_WEBKIT2
+    void* request = NULL;
+    #else
     WebKitWebView* web_view = WEBKIT_WEB_VIEW (midori_view_get_web_view (view));
     WebKitWebFrame* web_frame = webkit_web_view_get_main_frame (web_view);
     WebKitWebDataSource* source = webkit_web_frame_get_data_source (web_frame);
     WebKitNetworkRequest* request = webkit_web_data_source_get_request (source);
-    SoupMessage* message = midori_map_get_message (webkit_network_request_get_message (request));
-    GTlsCertificate* tls_cert;
-    GTlsCertificateFlags tls_flags;
-
-    g_return_if_fail (message);
-    g_object_get (message, "tls-certificate", &tls_cert, "tls-errors", &tls_flags, NULL);
-
+    #endif
+    midori_view_get_tls_info (view, request, &tls_cert, &tls_flags, &hostname);
     if (tls_cert == NULL)
+    {
+        g_free (hostname);
         return;
+    }
 
     #ifdef HAVE_GCR
     GByteArray* der_cert;
     GcrCertificate* gcr_cert;
     GtkWidget* details;
-    SoupURI* uri = soup_message_get_uri (message);
 
     g_object_get (tls_cert, "certificate", &der_cert, NULL);
     gcr_cert = gcr_simple_certificate_new (
@@ -1412,7 +1417,7 @@ midori_location_action_show_page_info (GtkWidget* widget,
     details = (GtkWidget*)gcr_certificate_details_widget_new (gcr_cert);
     gtk_widget_show (details);
     gtk_container_add (GTK_CONTAINER (box), details);
-    if (gcr_trust_is_certificate_pinned (gcr_cert, GCR_PURPOSE_SERVER_AUTH, uri->host, NULL, NULL))
+    if (gcr_trust_is_certificate_pinned (gcr_cert, GCR_PURPOSE_SERVER_AUTH, hostname, NULL, NULL))
         gtk_dialog_add_buttons (GTK_DIALOG (dialog),
             ("_Don't trust this website"), MIDORI_CERT_REVOKE, NULL);
     else if (tls_flags > 0)
@@ -1422,7 +1427,7 @@ midori_location_action_show_page_info (GtkWidget* widget,
         gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Export certificate"), MIDORI_CERT_EXPORT),
         "secondary", TRUE, NULL);
 
-    g_object_set_data_full (G_OBJECT (gcr_cert), "peer", g_strdup (uri->host), (GDestroyNotify)g_free);
+    g_object_set_data_full (G_OBJECT (gcr_cert), "peer", hostname, (GDestroyNotify)g_free);
     g_object_set_data_full (G_OBJECT (dialog), "gcr-cert", gcr_cert, (GDestroyNotify)g_object_unref);
     g_signal_connect (dialog, "response",
         G_CALLBACK (midori_location_action_cert_response_cb), gcr_cert);
@@ -1431,16 +1436,17 @@ midori_location_action_show_page_info (GtkWidget* widget,
     gtk_window_set_default_size (GTK_WINDOW (dialog), 250, 200);
     #endif
     #else
-    const gchar* tls_error = midori_location_action_tls_flags_to_string (tls_flags);
-
     if (!g_tls_certificate_get_issuer (tls_cert))
         gtk_box_pack_start (box, gtk_label_new (_("Self-signed")), FALSE, FALSE, 0);
 
-    gtk_box_pack_start (box, gtk_label_new (tls_error), FALSE, FALSE, 0);
+    if (tls_flags > 0)
+    {
+        const gchar* tls_error = midori_location_action_tls_flags_to_string (tls_flags);
+        gtk_box_pack_start (box, gtk_label_new (tls_error), FALSE, FALSE, 0);
+    }
     #endif
 
     g_object_unref (tls_cert);
-#endif
 }
 #endif
 
@@ -1458,6 +1464,10 @@ midori_location_action_icon_released_cb (GtkWidget*           widget,
 
     if (icon_pos == GTK_ICON_ENTRY_PRIMARY)
     {
+        /* No "security" window for blank pages */
+        if (midori_uri_is_blank (MIDORI_LOCATION_ACTION (action)->text))
+            return;
+
         const gchar* title = _("Security details");
         GtkWidget* content_area;
         GtkWidget* hbox;
@@ -1742,6 +1752,36 @@ midori_location_action_set_secondary_icon (MidoriLocationAction* location_action
     }
 }
 
+/**
+ * midori_location_action_primary_icon:
+ * @location_action: a #MidoriLocationAction
+ * @icon: a list of icon names, preferred icon first
+ * @tooltip: The tooltip to show
+ *
+ * The primary icon is mutually exclusive with the security hint.
+ *
+ * Since: 0.5.1
+ **/
+void
+midori_location_action_set_primary_icon (MidoriLocationAction* location_action,
+                                         GIcon*                icon,
+                                         const gchar*          tooltip)
+{
+    GSList* proxies;
+
+    g_return_if_fail (MIDORI_IS_LOCATION_ACTION (location_action));
+
+    proxies = gtk_action_get_proxies (GTK_ACTION (location_action));
+
+    for (; proxies != NULL; proxies = g_slist_next (proxies))
+    if (GTK_IS_TOOL_ITEM (proxies->data))
+    {
+        GtkWidget* entry = midori_location_action_entry_for_proxy (proxies->data);
+        gtk_entry_set_icon_from_gicon (GTK_ENTRY (entry), GTK_ICON_ENTRY_PRIMARY, icon);
+        gtk_icon_entry_set_tooltip (GTK_ICON_ENTRY (entry), GTK_ICON_ENTRY_PRIMARY, tooltip);
+    }
+}
+
 /**
  * midori_location_action_set_security_hint:
  * @location_action: a #MidoriLocationAction
@@ -1756,39 +1796,31 @@ void
 midori_location_action_set_security_hint (MidoriLocationAction* location_action,
                                           MidoriSecurity        hint)
 {
-    GSList* proxies;
+    GIcon* icon;
+    gchar* tooltip;
 
     g_return_if_fail (MIDORI_IS_LOCATION_ACTION (location_action));
 
-    proxies = gtk_action_get_proxies (GTK_ACTION (location_action));
-
-    for (; proxies != NULL; proxies = g_slist_next (proxies))
-    if (GTK_IS_TOOL_ITEM (proxies->data))
+    if (hint == MIDORI_SECURITY_UNKNOWN)
     {
-        GtkWidget* entry = midori_location_action_entry_for_proxy (proxies->data);
-
-        if (hint == MIDORI_SECURITY_UNKNOWN)
-        {
-            gchar* icon_names[] = { "channel-insecure-symbolic", "lock-insecure", "dialog-information", NULL };
-            gtk_entry_set_icon_from_gicon (GTK_ENTRY (entry), GTK_ICON_ENTRY_PRIMARY,
-                g_themed_icon_new_from_names (icon_names, -1));
-            gtk_icon_entry_set_tooltip (GTK_ICON_ENTRY (entry),
-                GTK_ICON_ENTRY_PRIMARY, _("Not verified"));
-        }
-        else if (hint == MIDORI_SECURITY_TRUSTED)
-        {
-            gchar* icon_names[] = { "channel-secure-symbolic", "lock-secure", "locked", NULL };
-            gtk_entry_set_icon_from_gicon (GTK_ENTRY (entry), GTK_ICON_ENTRY_PRIMARY,
-                g_themed_icon_new_from_names (icon_names, -1));
-            gtk_icon_entry_set_tooltip (GTK_ICON_ENTRY (entry),
-                GTK_ICON_ENTRY_PRIMARY, _("Verified and encrypted connection"));
-        }
-        else if (hint == MIDORI_SECURITY_NONE)
-        {
-            gtk_entry_set_icon_from_gicon (GTK_ENTRY (entry), GTK_ICON_ENTRY_PRIMARY,
-                g_themed_icon_new_with_default_fallbacks ("text-html-symbolic"));
-            gtk_icon_entry_set_tooltip (GTK_ICON_ENTRY (entry),
-                GTK_ICON_ENTRY_PRIMARY, _("Open, unencrypted connection"));
-        }
+        gchar* icon_names[] = { "channel-insecure-symbolic", "lock-insecure", "dialog-information", NULL };
+        icon = g_themed_icon_new_from_names (icon_names, -1);
+        tooltip = _("Not verified");
     }
+    else if (hint == MIDORI_SECURITY_TRUSTED)
+    {
+        gchar* icon_names[] = { "channel-secure-symbolic", "lock-secure", "locked", NULL };
+        icon = g_themed_icon_new_from_names (icon_names, -1);
+        tooltip = _("Verified and encrypted connection");
+    }
+    else if (hint == MIDORI_SECURITY_NONE)
+    {
+        icon = g_themed_icon_new_with_default_fallbacks ("text-html-symbolic");
+        tooltip = _("Open, unencrypted connection");
+    }
+    else
+        g_assert_not_reached ();
+
+    midori_location_action_set_primary_icon (location_action, icon, tooltip);
+    g_object_unref (icon);
 }
