@@ -82,6 +82,12 @@ void
 midori_view_set_uri                    (MidoriView*        view,
                                         const gchar*       uri);
 
+void
+midori_view_set_html                   (MidoriView*        view,
+                                        const gchar*       data,
+                                        const gchar*       uri,
+                                        void*              web_frame);
+
 void
 midori_view_set_overlay_text           (MidoriView*        view,
                                         const gchar*       text);
@@ -248,6 +254,13 @@ midori_view_set_colors                 (MidoriView*        view,
                                         GdkColor*          fg_color,
                                         GdkColor*          bg_color);
 
+gboolean
+midori_view_get_tls_info               (MidoriView*        view,
+                                        void*              request,
+                                        GTlsCertificate**     tls_cert,
+                                        GTlsCertificateFlags* tls_flags,
+                                        gchar**               hostname);
+
 G_END_DECLS
 
 #endif /* __MIDORI_VIEW_H__ */
