@@ -532,7 +532,7 @@ notify_default_encoding_cb (GObject*    object,
 
     web_settings = MIDORI_WEB_SETTINGS (object);
 
-    g_object_get (object, "default-encoding", &string, NULL);
+    g_object_get (object, pspec->name, &string, NULL);
     encoding = string ? string : "";
     if (!strcmp (encoding, "BIG5"))
         web_settings->preferred_encoding = MIDORI_ENCODING_CHINESE;
@@ -581,7 +581,7 @@ midori_web_settings_init (MidoriWebSettings* web_settings)
     " * { -webkit-appearance: none !important }");
     #endif
 
-    g_signal_connect (web_settings, "notify::default-encoding",
+    g_signal_connect (web_settings, "notify::default-charset",
                       G_CALLBACK (notify_default_encoding_cb), NULL);
     g_signal_connect (web_settings, "notify::default-font-family",
                       G_CALLBACK (notify_default_font_family_cb), NULL);
@@ -624,6 +624,19 @@ midori_web_settings_has_plugin_support (void)
     #endif
 }
 
+/**
+ * midori_web_settings_skip_plugin:
+ *
+ * Returns: %TRUE if the passed plugin shouldn't be shown in UI listings.
+ *
+ * Since: 0.5.1
+ **/
+gboolean
+midori_web_settings_skip_plugin (const gchar* path)
+{
+    return !path || strstr (path, "npwrapper.") || strstr (path, "plugins-wrapped");
+}
+
 /**
  * midori_web_settings_get_site_data_policy:
  *
@@ -781,8 +794,8 @@ generate_ident_string (MidoriWebSettings* web_settings,
     const int webcore_major = WEBKIT_USER_AGENT_MAJOR_VERSION;
     const int webcore_minor = WEBKIT_USER_AGENT_MINOR_VERSION;
     #else
-    const int webcore_major = WEBKIT_MAJOR_VERSION;
-    const int webcore_minor = WEBKIT_MINOR_VERSION;
+    const int webcore_major = 537;
+    const int webcore_minor = 32;
     #endif
 
     #if WEBKIT_CHECK_VERSION (1, 1, 18)
@@ -819,6 +832,7 @@ generate_ident_string (MidoriWebSettings* web_settings,
     }
 }
 
+#ifndef HAVE_WEBKIT2
 /* Provide a new way for SoupSession to assume an 'Accept-Language'
    string automatically from the return value of g_get_language_names(),
    properly formatted according to RFC2616.
@@ -933,6 +947,7 @@ midori_web_settings_get_accept_language (MidoriWebSettings* settings)
         midori_web_settings_update_accept_language (settings);
     return settings->accept;
 }
+#endif
 
 static void
 midori_web_settings_process_stylesheets (MidoriWebSettings* settings,
@@ -964,28 +979,28 @@ midori_web_settings_set_property (GObject*      object,
         switch (web_settings->preferred_encoding)
         {
         case MIDORI_ENCODING_CHINESE:
-            g_object_set (object, "default-encoding", "BIG5", NULL);
+            g_object_set (object, "default-charset", "BIG5", NULL);
             break;
         case MIDORI_ENCODING_CHINESE_SIMPLIFIED:
-            g_object_set (object, "default-encoding", "GB18030", NULL);
+            g_object_set (object, "default-charset", "GB18030", NULL);
             break;
         case MIDORI_ENCODING_JAPANESE:
-            g_object_set (object, "default-encoding", "SHIFT_JIS", NULL);
+            g_object_set (object, "default-charset", "SHIFT_JIS", NULL);
             break;
        case MIDORI_ENCODING_KOREAN:
-            g_object_set (object, "default-encoding", "EUC-KR", NULL);
+            g_object_set (object, "default-charset", "EUC-KR", NULL);
             break;
         case MIDORI_ENCODING_RUSSIAN:
-            g_object_set (object, "default-encoding", "KOI8-R", NULL);
+            g_object_set (object, "default-charset", "KOI8-R", NULL);
             break;
         case MIDORI_ENCODING_UNICODE:
-            g_object_set (object, "default-encoding", "UTF-8", NULL);
+            g_object_set (object, "default-charset", "UTF-8", NULL);
             break;
         case MIDORI_ENCODING_WESTERN:
-            g_object_set (object, "default-encoding", "ISO-8859-1", NULL);
+            g_object_set (object, "default-charset", "ISO-8859-1", NULL);
             break;
         case MIDORI_ENCODING_CUSTOM:
-            g_object_set (object, "default-encoding", "", NULL);
+            g_object_set (object, "default-charset", "", NULL);
         }
         break;
 
@@ -996,7 +1011,9 @@ midori_web_settings_set_property (GObject*      object,
     case PROP_ENABLE_PLUGINS:
         g_object_set (web_settings,
            WEB_SETTINGS_STRING ("enable-plugins"), g_value_get_boolean (value),
-        #if WEBKIT_CHECK_VERSION (1, 1, 22)
+        #if HAVE_WEBKIT2
+            "enable-java", g_value_get_boolean (value),
+        #elif WEBKIT_CHECK_VERSION (1, 1, 22)
             "enable-java-applet", g_value_get_boolean (value),
         #endif
             NULL);
@@ -1033,9 +1050,19 @@ midori_web_settings_set_property (GObject*      object,
         break;
     case PROP_PREFERRED_LANGUAGES:
         katze_assign (web_settings->http_accept_language, g_value_dup_string (value));
+        #ifdef HAVE_WEBKIT2
+        WebKitWebContext* context = webkit_web_context_get_default ();
+        gchar** languages = web_settings->http_accept_language
+            ? g_strsplit_set (web_settings->http_accept_language, ",; ", -1)
+            : g_strdupv ((gchar**)g_get_language_names ());
+        webkit_web_context_set_preferred_languages (context, (const gchar* const*)languages);
+        webkit_web_context_set_spell_checking_languages (context, (const gchar* const*)languages);
+        g_strfreev (languages);
+        #else
         g_object_set (web_settings, "spell-checking-languages",
                       web_settings->http_accept_language, NULL);
         midori_web_settings_update_accept_language (web_settings);
+        #endif
         break;
     case PROP_SITE_DATA_RULES:
         katze_assign (web_settings->site_data_rules, g_value_dup_string (value));
@@ -1205,8 +1232,12 @@ midori_web_settings_get_property (GObject*    object,
             WEB_SETTINGS_STRING ("enable-fullscreen")));
         break;
     case PROP_USER_STYLESHEET_URI:
+#ifdef HAVE_WEBKIT2
+        g_value_set_string (value, web_settings->user_stylesheet_uri);
+#else
         g_value_take_string (value, katze_object_get_string (web_settings,
             WEB_SETTINGS_STRING ("user-stylesheet-uri")));
+#endif
         break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -1261,7 +1292,11 @@ midori_web_settings_process_stylesheets (MidoriWebSettings* settings,
 
     /* data: uri prefix from Source/WebCore/page/Page.cpp:700 in WebKit */
     encoded = g_strconcat ("data:text/css;charset=utf-8;base64,", css->str, NULL);
+    #ifdef HAVE_WEBKIT2
+    /* TODO: webkit_web_view_group_add_user_style_sheet */
+    #else
     g_object_set (settings, WEB_SETTINGS_STRING ("user-stylesheet-uri"), encoded, NULL);
+    #endif
     g_free (encoded);
     g_string_free (css, TRUE);
 }
