@@ -175,6 +175,9 @@ midori_web_settings_get_system_name        (gchar**            architecture,
 gboolean
 midori_web_settings_has_plugin_support     (void);
 
+gboolean
+midori_web_settings_skip_plugin            (const gchar* path);
+
 typedef enum
 {
     MIDORI_SITE_DATA_UNDETERMINED,
@@ -187,9 +190,6 @@ MidoriSiteDataPolicy
 midori_web_settings_get_site_data_policy   (MidoriWebSettings* settings,
                                             const gchar*       uri);
 
-const gchar*
-midori_web_settings_get_accept_language    (MidoriWebSettings* settings);
-
 MidoriWebSettings*
 midori_settings_new_full                   (gchar***           extensions);
 
