@@ -17,9 +17,11 @@
 #include "midori-bookmarks.h"
 #include "midori-browser.h"
 #include "midori-extension.h"
+#include "midori-frontend.h"
 #include "midori-locationaction.h"
 #include "midori-panel.h"
 #include "midori-preferences.h"
+#include "midori-privatedata.h"
 #include "midori-searchaction.h"
 #include "midori-view.h"
 #include "midori-websettings.h"
