@@ -109,11 +109,7 @@ sokoke_gtk_action_count_modifiers       (GtkAction* action);
 gboolean
 sokoke_prefetch_uri                     (MidoriWebSettings*  settings,
                                          const char*         uri,
-#ifndef HAVE_WEBKIT2
-                                         SoupAddressCallback callback,
-#else
-                                         void*               callback,
-#endif
+                                         GCallback           callback,
                                          gpointer            user_data);
 
 gboolean
