@@ -231,12 +231,15 @@ midori_extensions_treeview_render_icon_cb (GtkTreeViewColumn* column,
                                            GtkWidget*         treeview)
 {
     MidoriExtension* extension;
+    gchar* stock_id;
     gtk_tree_model_get (model, iter, 0, &extension, -1);
 
-    g_object_set (renderer, "stock-id", STOCK_EXTENSION,
+    stock_id = katze_object_get_object (extension, "stock-id");
+    g_object_set (renderer, "stock-id", stock_id ? stock_id : STOCK_EXTENSION,
                             "stock-size", GTK_ICON_SIZE_BUTTON,
                             "sensitive", midori_extension_is_prepared (extension),
                             "xpad", 4, NULL);
+    g_free (stock_id);
     g_object_unref (extension);
 }
 
@@ -276,8 +279,12 @@ midori_extensions_treeview_render_text_cb (GtkTreeViewColumn* column,
     name = katze_object_get_string (extension, "name");
     version = katze_object_get_string (extension, "version");
     desc = katze_object_get_string (extension, "description");
-    text = g_markup_printf_escaped ("<b>%s</b> %s\n%s",
-        name, version && *version ? version : "", desc);
+    if (katze_object_get_boolean (extension, "use-markup"))
+        text = g_strdup_printf ("<b>%s</b> %s\n%s",
+            name, version && *version ? version : "", desc);
+    else
+        text = g_markup_printf_escaped ("<b>%s</b> %s\n%s",
+            name, version && *version ? version : "", desc);
     g_free (name);
     g_free (version);
     g_free (desc);
@@ -425,6 +432,29 @@ midori_extensions_treeview_button_pressed_cb (GtkWidget*      view,
     return ret;
 }
 
+static gboolean
+extensions_column_search_equal_func (GtkTreeModel* model,
+                                     gint          column,
+                                     const gchar*  key,
+                                     GtkTreeIter*  iter,
+                                     gpointer      search_data)
+{
+    MidoriExtension* extension;
+    gchar* name;
+    gchar* lower;
+    gboolean match;
+
+    gtk_tree_model_get (model, iter, 0, &extension, -1);
+    name = katze_object_get_string (extension, "name");
+    lower = g_utf8_strdown (name, -1);
+    match = !strstr (lower, key);
+
+    g_free (lower);
+    g_free (name);
+
+    return match;
+}
+
 static void
 midori_extensions_init (MidoriExtensions* extensions)
 {
@@ -487,6 +517,9 @@ midori_extensions_init (MidoriExtensions* extensions)
         "signal::row-activated",
         midori_extensions_treeview_row_activated_cb, extensions,
         NULL);
+    gtk_tree_view_set_search_column (GTK_TREE_VIEW (extensions->treeview), 0);
+    gtk_tree_view_set_search_equal_func (GTK_TREE_VIEW (extensions->treeview),
+                                         extensions_column_search_equal_func, NULL, NULL);
     gtk_widget_show (extensions->treeview);
     gtk_box_pack_start (GTK_BOX (extensions), extensions->treeview, TRUE, TRUE, 0);
 }
