@@ -27,7 +27,6 @@ struct _MidoriFindbar
     GtkToolItem* previous;
     GtkToolItem* next;
     GtkToolItem* find_case;
-    GtkToolItem* find_highlight;
     GtkToolItem* find_close;
     gboolean find_typing;
 };
@@ -68,10 +67,10 @@ midori_findbar_done (MidoriFindbar* findbar)
     MidoriBrowser* browser = midori_browser_get_for_widget (GTK_WIDGET (findbar));
     GtkWidget* view = midori_browser_get_current_tab (browser);
 
-    midori_view_unmark_text_matches (MIDORI_VIEW (view));
+    midori_tab_unmark_text_matches (MIDORI_TAB (view));
     gtk_widget_hide (GTK_WIDGET (findbar));
     findbar->find_typing = FALSE;
-    gtk_window_set_focus (GTK_WINDOW (browser), view);
+    gtk_widget_grab_focus (view);
 }
 
 static gboolean
@@ -86,7 +85,7 @@ midori_findbar_find_key_press_event_cb (MidoriFindbar* findbar,
     else if (event->keyval == GDK_KEY_Return
           && (event->state & GDK_SHIFT_MASK))
     {
-        midori_findbar_find_text (findbar, NULL, FALSE);
+        midori_findbar_continue (findbar, FALSE);
         return TRUE;
     }
 
@@ -107,22 +106,20 @@ midori_findbar_case_sensitive (MidoriFindbar* findbar)
 }
 
 void
-midori_findbar_find_text (MidoriFindbar* findbar,
-                          const gchar*   text,
-                          gboolean       forward)
+midori_findbar_continue (MidoriFindbar* findbar,
+                         gboolean       forward)
 {
     MidoriBrowser* browser = midori_browser_get_for_widget (GTK_WIDGET (findbar));
+    const gchar* text;
     gboolean case_sensitive;
     GtkWidget* view;
 
     if (!(view = midori_browser_get_current_tab (browser)))
         return;
 
-    if (text == NULL)
-        text = gtk_entry_get_text (GTK_ENTRY (findbar->find_text));
-
+    text = gtk_entry_get_text (GTK_ENTRY (findbar->find_text));
     case_sensitive = midori_findbar_case_sensitive (findbar);
-    midori_view_search_text (MIDORI_VIEW (view), text, case_sensitive, forward);
+    midori_tab_find (MIDORI_TAB (view), text, case_sensitive, forward);
 }
 
 /**
@@ -141,39 +138,19 @@ midori_findbar_get_text (MidoriFindbar* findbar)
     return gtk_entry_get_text (GTK_ENTRY (findbar->find_text));
 }
 
-/**
- * midori_findbar_find:
- * @findbar: #MidoriFindbar
- * @forward: %TRUE to search forward
- *
- * Advance to the next match.
- *
- * Deprecated: 0.4.5: Use midori_findbar_find_text() instead.
- **/
 void
-midori_findbar_find (MidoriFindbar* findbar,
-                     gboolean       forward)
-{
-    midori_findbar_find_text (findbar, NULL, forward);
-}
-
-void
-midori_findbar_invoke (MidoriFindbar* findbar)
+midori_findbar_invoke (MidoriFindbar* findbar,
+                       const gchar*   selected_text)
 {
     if (gtk_widget_get_visible (GTK_WIDGET (findbar)))
         gtk_widget_grab_focus (GTK_WIDGET (findbar->find_text));
     else
     {
-        MidoriBrowser* browser = midori_browser_get_for_widget (findbar->find_text);
-        GtkWidget* view = midori_browser_get_current_tab (browser);
-        const gchar* text;
-
         midori_findbar_set_icon (findbar, GTK_ICON_ENTRY_PRIMARY, STOCK_EDIT_FIND);
         gtk_widget_show (GTK_WIDGET (findbar->find_case));
-        gtk_widget_show (GTK_WIDGET (findbar->find_highlight));
         gtk_widget_show (GTK_WIDGET (findbar->find_close));
-        if ((text = midori_view_get_selected_text (MIDORI_VIEW (view))))
-            gtk_entry_set_text (GTK_ENTRY (findbar->find_text), text);
+        if (selected_text != NULL)
+            gtk_entry_set_text (GTK_ENTRY (findbar->find_text), selected_text);
         gtk_widget_show (GTK_WIDGET (findbar));
         gtk_widget_grab_focus (GTK_WIDGET (findbar->find_text));
     }
@@ -183,14 +160,14 @@ static void
 midori_findbar_next_activate_cb (GtkWidget*     entry,
                                  MidoriFindbar* findbar)
 {
-    midori_findbar_find_text (findbar, NULL, TRUE);
+    midori_findbar_continue (findbar, TRUE);
 }
 
 static void
 midori_findbar_previous_clicked_cb (GtkWidget*     entry,
                                     MidoriFindbar* findbar)
 {
-    midori_findbar_find_text (findbar, NULL, FALSE);
+    midori_findbar_continue (findbar, FALSE);
 }
 
 static void
@@ -207,11 +184,12 @@ midori_findbar_preedit_changed_cb (GtkWidget*     entry,
 {
     MidoriBrowser* browser = midori_browser_get_for_widget (entry);
     GtkWidget* view = midori_browser_get_current_tab (browser);
-    midori_view_unmark_text_matches (MIDORI_VIEW (view));
+    midori_tab_unmark_text_matches (MIDORI_TAB (view));
     if (g_utf8_strlen (preedit, -1) >= 1)
     {
+        gboolean case_sensitive = midori_findbar_case_sensitive (findbar);
         midori_findbar_set_icon (findbar, GTK_ICON_ENTRY_SECONDARY, STOCK_EDIT_CLEAR);
-        midori_findbar_find_text (findbar, preedit, TRUE);
+        midori_tab_find (MIDORI_TAB (view), preedit, case_sensitive, TRUE);
     }
     else
         midori_findbar_set_icon (findbar, GTK_ICON_ENTRY_SECONDARY, NULL);
@@ -235,16 +213,6 @@ midori_findbar_text_focus_out_event_cb (GtkWidget*     entry,
     return FALSE;
 }
 
-static void
-midori_findbar_highlight_toggled_cb (GtkToggleToolButton* toolitem,
-                                     MidoriFindbar*       findbar)
-{
-    MidoriBrowser* browser = midori_browser_get_for_widget (GTK_WIDGET (findbar));
-    GtkWidget* view = midori_browser_get_current_tab (browser);
-    gboolean highlight = gtk_toggle_tool_button_get_active (toolitem);
-    midori_view_set_highlight_text_matches (MIDORI_VIEW (view), highlight);
-}
-
 static void
 midori_findbar_init (MidoriFindbar* findbar)
 {
@@ -277,10 +245,6 @@ midori_findbar_init (MidoriFindbar* findbar)
     gtk_container_add (GTK_CONTAINER (toolitem), findbar->find_text);
     gtk_tool_item_set_expand (GTK_TOOL_ITEM (toolitem), TRUE);
     gtk_toolbar_insert (GTK_TOOLBAR (findbar), toolitem, -1);
-    #if HAVE_HILDON
-    findbar->find_case = gtk_toggle_tool_button_new ();
-    findbar->find_highlight = gtk_toggle_tool_button_new ();
-    #else
     findbar->previous = gtk_tool_button_new_from_stock (GTK_STOCK_GO_BACK);
     g_signal_connect (findbar->previous, "clicked",
         G_CALLBACK (midori_findbar_previous_clicked_cb), findbar);
@@ -297,20 +261,9 @@ midori_findbar_init (MidoriFindbar* findbar)
     gtk_tool_button_set_label (GTK_TOOL_BUTTON (findbar->find_case), _("Match Case"));
     gtk_tool_item_set_is_important (GTK_TOOL_ITEM (findbar->find_case), TRUE);
     gtk_toolbar_insert (GTK_TOOLBAR (findbar), findbar->find_case, -1);
-    findbar->find_highlight = gtk_toggle_tool_button_new_from_stock (
-        GTK_STOCK_SELECT_ALL);
-    #endif
-    g_signal_connect (findbar->find_highlight, "toggled",
-                      G_CALLBACK (midori_findbar_highlight_toggled_cb), findbar);
-    gtk_tool_button_set_label (GTK_TOOL_BUTTON (findbar->find_highlight),
-                               _("Highlight Matches"));
-    gtk_tool_item_set_is_important (GTK_TOOL_ITEM (findbar->find_highlight), TRUE);
-    gtk_toolbar_insert (GTK_TOOLBAR (findbar), findbar->find_highlight, -1);
     toolitem = gtk_separator_tool_item_new ();
     gtk_separator_tool_item_set_draw (GTK_SEPARATOR_TOOL_ITEM (toolitem), FALSE);
-    #if !HAVE_HILDON
     gtk_tool_item_set_expand (GTK_TOOL_ITEM (toolitem), TRUE);
-    #endif
     gtk_toolbar_insert (GTK_TOOLBAR (findbar), toolitem, -1);
     findbar->find_close = gtk_tool_button_new_from_stock (GTK_STOCK_CLOSE);
     gtk_tool_button_set_label (GTK_TOOL_BUTTON (findbar->find_close),
@@ -338,25 +291,20 @@ midori_findbar_search_text (MidoriFindbar* findbar,
 {
     const gchar* text;
     gboolean case_sensitive;
-    gboolean highlight;
 
     midori_findbar_set_icon (findbar, GTK_ICON_ENTRY_PRIMARY, found ? STOCK_EDIT_FIND : STOCK_STOP);
 
     if (typing)
     {
-        MidoriBrowser* browser = midori_browser_get_for_widget (view);
         gint position = -1;
 
         findbar->find_typing = TRUE;
-        gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (
-            findbar->find_highlight), TRUE);
         gtk_widget_hide (GTK_WIDGET (findbar->find_case));
-        gtk_widget_hide (GTK_WIDGET (findbar->find_highlight));
         gtk_widget_hide (GTK_WIDGET (findbar->find_close));
         if (!gtk_widget_get_visible (GTK_WIDGET (findbar)))
             gtk_entry_set_text (GTK_ENTRY (findbar->find_text), "");
         gtk_widget_show (GTK_WIDGET (findbar));
-        gtk_window_set_focus (GTK_WINDOW (browser), findbar->find_text);
+        gtk_widget_grab_focus (findbar->find_text);
         gtk_editable_insert_text (GTK_EDITABLE (findbar->find_text),
                                  typing, -1, &position);
         gtk_editable_set_position (GTK_EDITABLE (findbar->find_text), -1);
@@ -365,10 +313,7 @@ midori_findbar_search_text (MidoriFindbar* findbar,
     {
         text = gtk_entry_get_text (GTK_ENTRY (findbar->find_text));
         case_sensitive = midori_findbar_case_sensitive (findbar);
-        midori_view_mark_text_matches (MIDORI_VIEW (view), text, case_sensitive);
-        highlight = gtk_toggle_tool_button_get_active (
-            GTK_TOGGLE_TOOL_BUTTON (findbar->find_highlight));
-        midori_view_set_highlight_text_matches (MIDORI_VIEW (view), highlight);
+        midori_tab_find (MIDORI_TAB (view), text, case_sensitive, TRUE);
     }
 }
 
